#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-markup
version:              0.8.3.0
visibility:           public
id:                   blaze-markup-0.8.3.0-DiaEcmdFIWULBQgZYUzUEx
key:                  blaze-markup-0.8.3.0-DiaEcmdFIWULBQgZYUzUEx
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  3f8bf9b73be5e5d171a68c247a7e7cb1
exposed:              True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8

import-dirs:          /usr/lib/ghc-9.6.6/site-local/blaze-markup-0.8.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/blaze-markup-0.8.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/blaze-markup-0.8.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-markup
hs-libraries:         HSblaze-markup-0.8.3.0-DiaEcmdFIWULBQgZYUzUEx
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-6z94n90ZejvLe4Rn4IUYhT
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock

haddock-html:         /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

